@@ -3,7 +3,7 @@
  * Zend Framework (http://framework.zend.com/)
  *
  * @link      http://github.com/zendframework/zf2 for the canonical source repository
- * @copyright Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license   http://framework.zend.com/license/new-bsd New BSD License
  */
 
@@ -11,6 +11,6 @@ namespace Zend\File\Transfer\Exception;
 
 use Zend\File\Exception;
 
-class BadMethodCallException extends Exception\BadMethodCallException implements
-    ExceptionInterface
-{}
+class BadMethodCallException extends Exception\BadMethodCallException implements ExceptionInterface
+{
+}
