@@ -3,7 +3,7 @@
  * Zend Framework (http://framework.zend.com/)
 *
 * @link      http://github.com/zendframework/zf2 for the canonical source repository
-* @copyright Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
+* @copyright Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
 * @license   http://framework.zend.com/license/new-bsd New BSD License
 */
 
@@ -62,7 +62,7 @@ class Backtrace implements ProcessorInterface
     /**
      * Provide backtrace as slim as possible
      *
-     * @return  array:
+     * @return array[]
      */
     protected function getBacktrace()
     {
@@ -70,10 +70,6 @@ class Backtrace implements ProcessorInterface
             return debug_backtrace(DEBUG_BACKTRACE_IGNORE_ARGS, $this->traceLimit);
         }
 
-        if (PHP_VERSION_ID >= 50306) {
-            return debug_backtrace(DEBUG_BACKTRACE_IGNORE_ARGS);
-        }
-
-        return debug_backtrace();
+        return debug_backtrace(DEBUG_BACKTRACE_IGNORE_ARGS);
     }
 }
