@@ -686,22 +686,30 @@ abstract class AbstractHttpControllerTestCase extends AbstractControllerTestCase
     private function queryContentContainsAssertion($path, $match, $useXpath = false)
     {
         $result = $this->query($path, $useXpath);
+
         if ($result->count() == 0) {
             throw new PHPUnit_Framework_ExpectationFailedException(sprintf(
                 'Failed asserting node DENOTED BY %s EXISTS',
                 $path
             ));
         }
+
+        $nodeValues = array();
+
         foreach ($result as $node) {
             if ($node->nodeValue == $match) {
                 $this->assertEquals($match, $node->nodeValue);
                 return;
             }
+
+            $nodeValues[] = $node->nodeValue;
         }
+
         throw new PHPUnit_Framework_ExpectationFailedException(sprintf(
-            'Failed asserting node denoted by %s CONTAINS content "%s"',
+            'Failed asserting node denoted by %s CONTAINS content "%s", Contents: [%s]',
             $path,
-            $match
+            $match,
+            implode(',', $nodeValues)
         ));
     }
 
